@@ -27,7 +27,7 @@ class ContainerMap:
     generator = None
     logger = None
 
-    def __init__(self, conn_string_name: str, container_name: str, map_file_name: str = "map.json"):
+    def __init__(self, conn_string_name, container_name, map_file_name="map.json"):
         """Creates a mapping object utilizing a SAS Token Connection string in the format provided by Azure Portal
 
         Args:
